@@ -20,7 +20,6 @@ const (
 	DialectTiDB       Dialect = database.DialectTiDB
 	DialectVertica    Dialect = database.DialectVertica
 	DialectYdB        Dialect = database.DialectYdB
-	DialectDuckDB     Dialect = database.DialectDuckDB
 )
 
 func init() {
@@ -53,8 +52,6 @@ func SetDialect(s string) error {
 		d = dialect.Ydb
 	case "turso":
 		d = dialect.Turso
-	case "duckdb":
-		d = dialect.Duckdb
 	default:
 		return fmt.Errorf("%q: unknown dialect", s)
 	}
