@@ -259,10 +259,7 @@ func (p *Provider) initialize(ctx context.Context, useSessionLocker bool) (*sql.
 			p.mu.Unlock()
 			// Use a detached context to unlock the session. This is because the context passed to
 			// SessionLock may have been canceled, and we don't want to cancel the unlock.
-			//
-			// TODO(mf): use context.WithoutCancel added in go1.21
-			detachedCtx := context.Background()
-			return multierr.Append(l.SessionUnlock(detachedCtx, conn), conn.Close())
+			return multierr.Append(l.SessionUnlock(context.WithoutCancel(ctx), conn), conn.Close())
 		}
 	}
 	// If versioning is enabled, ensure the version table exists. For ad-hoc migrations, we don't
