@@ -5,7 +5,6 @@ import (
 	"database/sql"
 	"errors"
 	"fmt"
-	"io/fs"
 	"math"
 	"math/rand"
 	"os"
@@ -507,10 +506,9 @@ func TestNoVersioning(t *testing.T) {
 			upResult, err := p.Up(ctx)
 			check.NoError(t, err)
 			check.Number(t, len(upResult), 2)
-			// Confirm no changes to the versioned schema in the DB
-			currentVersion, err := p.GetDBVersion(ctx)
-			check.NoError(t, err)
-			check.Number(t, baseVersion, currentVersion)
+			// When versioning is disabled, we cannot track the version of the seed files.
+			_, err = p.GetDBVersion(ctx)
+			check.HasError(t, err)
 			seedOwnerCount, err := countSeedOwners(db)
 			check.NoError(t, err)
 			check.Number(t, seedOwnerCount, wantSeedOwnerCount)
@@ -520,10 +518,9 @@ func TestNoVersioning(t *testing.T) {
 			downResult, err := p.DownTo(ctx, 0)
 			check.NoError(t, err)
 			check.Number(t, len(downResult), 2)
-			// Confirm no changes to the versioned schema in the DB
-			currentVersion, err := p.GetDBVersion(ctx)
-			check.NoError(t, err)
-			check.Number(t, baseVersion, currentVersion)
+			// When versioning is disabled, we cannot track the version of the seed files.
+			_, err = p.GetDBVersion(ctx)
+			check.HasError(t, err)
 			seedOwnerCount, err := countSeedOwners(db)
 			check.NoError(t, err)
 			check.Number(t, seedOwnerCount, 0)
@@ -775,11 +772,12 @@ func TestProviderApply(t *testing.T) {
 	check.Bool(t, errors.Is(err, goose.ErrNotApplied), true)
 }
 
-func TestHasPending(t *testing.T) {
+func TestPending(t *testing.T) {
 	t.Parallel()
 	t.Run("allow_out_of_order", func(t *testing.T) {
 		ctx := context.Background()
-		p, err := goose.NewProvider(goose.DialectSQLite3, newDB(t), newFsys(),
+		fsys := newFsys()
+		p, err := goose.NewProvider(goose.DialectSQLite3, newDB(t), fsys,
 			goose.WithAllowOutofOrder(true),
 		)
 		check.NoError(t, err)
@@ -788,6 +786,12 @@ func TestHasPending(t *testing.T) {
 		check.NoError(t, err)
 		_, err = p.ApplyVersion(ctx, 3, true)
 		check.NoError(t, err)
+		// Even though the latest migration HAS been applied, there are still pending out-of-order
+		// migrations.
+		current, target, err := p.GetVersions(ctx)
+		check.NoError(t, err)
+		check.Number(t, current, 3)
+		check.Number(t, target, len(fsys))
 		hasPending, err := p.HasPending(ctx)
 		check.NoError(t, err)
 		check.Bool(t, hasPending, true)
@@ -798,27 +802,44 @@ func TestHasPending(t *testing.T) {
 		hasPending, err = p.HasPending(ctx)
 		check.NoError(t, err)
 		check.Bool(t, hasPending, false)
+		current, target, err = p.GetVersions(ctx)
+		check.NoError(t, err)
+		check.Number(t, current, target)
 	})
 	t.Run("disallow_out_of_order", func(t *testing.T) {
 		ctx := context.Background()
-		p, err := goose.NewProvider(goose.DialectSQLite3, newDB(t), newFsys(),
-			goose.WithAllowOutofOrder(false),
-		)
-		check.NoError(t, err)
-		// Some migrations have been applied.
-		_, err = p.ApplyVersion(ctx, 1, true)
-		check.NoError(t, err)
-		_, err = p.ApplyVersion(ctx, 2, true)
-		check.NoError(t, err)
-		hasPending, err := p.HasPending(ctx)
-		check.NoError(t, err)
-		check.Bool(t, hasPending, true)
-		_, err = p.Up(ctx)
-		check.NoError(t, err)
-		// All migrations have been applied.
-		hasPending, err = p.HasPending(ctx)
-		check.NoError(t, err)
-		check.Bool(t, hasPending, false)
+		fsys := newFsys()
+
+		run := func(t *testing.T, versionToApply int64) {
+			p, err := goose.NewProvider(goose.DialectSQLite3, newDB(t), fsys,
+				goose.WithAllowOutofOrder(false),
+			)
+			check.NoError(t, err)
+			// Some migrations have been applied.
+			_, err = p.ApplyVersion(ctx, 1, true)
+			check.NoError(t, err)
+			_, err = p.ApplyVersion(ctx, versionToApply, true)
+			check.NoError(t, err)
+			// TODO(mf): revisit the pending check behavior in addition to the HasPending
+			// method.
+			current, target, err := p.GetVersions(ctx)
+			check.NoError(t, err)
+			check.Number(t, current, versionToApply)
+			check.Number(t, target, len(fsys))
+			_, err = p.HasPending(ctx)
+			check.HasError(t, err)
+			check.Contains(t, err.Error(), "missing (out-of-order) migration")
+			_, err = p.Up(ctx)
+			check.HasError(t, err)
+			check.Contains(t, err.Error(), "missing (out-of-order) migration")
+		}
+
+		t.Run("latest_version", func(t *testing.T) {
+			run(t, int64(len(fsys)))
+		})
+		t.Run("latest_version_minus_one", func(t *testing.T) {
+			run(t, int64(len(fsys)-1))
+		})
 	})
 }
 
@@ -1089,7 +1110,7 @@ func newMapFile(data string) *fstest.MapFile {
 	}
 }
 
-func newFsys() fs.FS {
+func newFsys() fstest.MapFS {
 	return fstest.MapFS{
 		"00001_users_table.sql":    newMapFile(runMigration1),
 		"00002_posts_table.sql":    newMapFile(runMigration2),
